/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.action;

import java.util.Hashtable;
import roboplayer.body.Body;
import roboplayer.memory.Memory;

/**
 * Helper function for various technical Actions.
 * @author Krzysztof Langner
 * @version 0.2
 */
public class Actions
{
  //----------------------------------------------------------------------------
  /** Constructor */
  public Actions(Body body, Memory memory)
  {
    loadActions(body, memory);
  }

  /**
   * Executes given Action
   */
  public void execute(String actionName)
  {
    BaseAction a = (BaseAction)actions.get(actionName.toLowerCase());

    if(a != null)
      a.run();
  }

  /**
   * Load Actions. Current this function loads fixed Actions.
   * It should be changed to load Action from config file.
   */
  private void loadActions(Body body, Memory memory)
  {
    addAction(new PrepareToGameAction(body, memory));
    addAction(new ClearOrPassAction(body, memory));
    addAction(new DashToDefaultPosAction(body, memory));
    addAction(new FindBallAction(body, memory));
    addAction(new InterceptBallAction(body, memory));
    addAction(new KeepDefensivePosAction(body, memory));
    addAction(new ShootOrPassAction(body, memory));
    addAction(new ShootAction(body, memory));
    addAction(new LookAroundAction(body, memory));
  }

  /**
   * Add Action to the list.
   */
  private void addAction(BaseAction action)
  {
    actions.put(action.getName().toLowerCase(), action);
  }

  //===========================================================================
  // Private members
  /** robot which is controled by this Brain */
  private Hashtable   actions = new Hashtable();
}