/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.action;

import roboplayer.geometry.Polar;
import roboplayer.geometry.Vector2d;
import roboplayer.geometry.Angle;
import roboplayer.memory.Memory;
import roboplayer.memory.ObjectInfo;
import roboplayer.body.Body;

import roboplayer.body.Settings;


public abstract class BaseAction {
  /**
   * Constructor
   */
  public BaseAction(String skillName, Body body, Memory memory)
  {
    this.skillName = skillName;
    this.body = body;
    this.memory = memory;
  }

  /**
   * Get name for this skill
   */
  public String getName(){
    return skillName;
  }

  /**
   * Execute this skill.
   */
  public abstract void run();


  //----------------------------------------------------------------------------
  // base actions

  //----------------------------------------------------------------------------
	/**
   * This function kicks ball at specified direction.
	 * Before kicking this function checks if there are any
	 * opponent players at this direction, and if nessesery
	 * changes direction.
   */
	protected void kickAt(double power, double dir)
	{
		ObjectInfo ball = memory.getVisualInfo().getBall();

    if(ball == null)
    {
//      System.out.println("Lost ball in kickAt");
      return;
    }

		if(dir > 90)
    {
      body.kick(1, 90);
    }
		else if(dir < -90)
    {
      body.kick(1, -90);
    }
    else
		  body.kick(power, dir);
	}

	//---------------------------------------------------------------------------
	/**
   * This function sends dash message
   */
	protected void dashTo(Polar object)
	{
    ObjectInfo player = memory.getVisualInfo().getNearestPlayer(new Polar(1, object.dir));

    /*if(player != null && Math.abs(player.dir - object.dir) < 5){
   		// Turn to object or
	  	// if we have correct direction then go to object
		  if( Math.abs(object.dir+45) > 5 )
      {
        System.out.println("Proba ominiecie - turn " + object.dir+45);
	  		body.turn(object.dir+45);
      }
  		else
      {
        System.out.println("Proba ominiecie - dash");
  			body.dash(40);
      }
    }
    else*/{
   		// Turn to object or
	  	// if we have correct direction then go to object
		  if( Math.abs(object.dir) > 5 )
      {
//        System.out.println("turn " + object.dir);
	  		body.turn(object.dir);
      }
  		else
      {
        double power;

        if(object.dist > 20){
          power = 40;
        }
        else{
          power = object.dist-body.getSpeed();
          power *= 1/Settings.getDashPowerRate();
        }

        // stamina controller
        power = Math.min(power, body.getStamina()-staminaMin + 130);
        if(power < 0){
          //System.out.println("Error: Power < 0");
          power = 0;
        }
//        System.out.println("dash " + power);
  			body.dash(power);
      }
    }
	}


	//---------------------------------------------------------------------------
	/**
   * This function sends dash message
   */
	protected void dashToBackward(Polar object)
	{
    ObjectInfo player = memory.getVisualInfo().getNearestPlayer(new Polar(1, object.dir));

 		// Turn to object or
  	// if we have correct direction then go to object
    double angle = Angle.Normalize(object.dir + 180.0);
    if( Math.abs(angle) > 5 )
    {
  		body.turn(angle);
    }
		else
    {
 			body.dash(-10);
    }
	}


	//---------------------------------------------------------------------------
	/**
   * This function sends dash message
   */
	protected void dashTo(Vector2d pos)
	{
    dashTo(memory.getVisualInfo().getPolar(pos));
	}


	//---------------------------------------------------------------------------
	/**
   * This function sends dash message
   */
	protected void dashToBackward(Vector2d pos)
	{
    dashToBackward(memory.getVisualInfo().getPolar(pos));
	}




	//----------------------------------------------------------------------------
  // Private memebers
  protected Body      body;
  protected Memory    memory;
  private   String	  skillName;
  /** Min allowed stamina */
  private  double     staminaMin = 100;
}
