/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.action;

import roboplayer.geometry.Polar;
import roboplayer.geometry.Angle;
import roboplayer.body.Body;
import roboplayer.memory.Memory;
import roboplayer.memory.VisualInfo;
import roboplayer.body.Settings;


class ShootAction extends BaseAction {
  /**
   * Constructor
   */
  public ShootAction(Body body, Memory memory) {
    super("Shoot", body, memory);
  }

  /**
   * Execute skill
   */
  public void run(){
    VisualInfo    visualInfo = memory.getVisualInfo();
    Polar         pos = visualInfo.getOpponentGoalPos();
		Polar         player;
    double        shootDir;

    if(pos == null)
      return;

    player = visualInfo.getOpponentPlayer(pos.dir);
    if(player != null)
    {
      double angle = Angle.Rad2Deg(Math.tan(3*Settings.getPlayerSize()/player.dist));
//      System.out.println("Shoot change angle = " + angle);
      shootDir = Angle.Normalize(pos.dir + angle);
    }
    else
      shootDir = pos.dir;

    kickAt(100, shootDir);
  }

}
