/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.body;

import java.io.RandomAccessFile;
import java.io.IOException;
import java.util.StringTokenizer;

public class Settings
{
	public static double	PITCH_LENGTH        = 105.0;
	public static double	PITCH_WIDTH	    = 68.0;
	public static double	PENALTY_AREA_LENGTH = 16.5;
	public static double	PENALTY_AREA_WIDTH  = 40.32;

  //----------------------------------------------------------------------------
  public static double getDashPowerRate()
  {
    return dash_power_rate;
  }

  //----------------------------------------------------------------------------
  public static double getGoalWidth()
  {
    return m_goalWidth;
  }

  //----------------------------------------------------------------------------
  public static double getPlayerSize()
  {
    return m_playerSize;
  }

  //----------------------------------------------------------------------------
  public static double getEffortDecThr()
  {
    return effort_dec_thr;
  }

  //----------------------------------------------------------------------------
  public static double getRecoverDecThr()
  {
    return recover_dec_thr;
  }

  //----------------------------------------------------------------------------
  public static double getStaminaMax()
  {
    return stamina_max;
  }

  //----------------------------------------------------------------------------
  /** Load paramters from file */
  public static void LoadParams(String fileName)
  {
    RandomAccessFile  input;
    String            line;
    long              length;
    StringTokenizer   tokenizer;
    String            key;
    String            value;

    try
    {
      input = new RandomAccessFile(fileName, "r");
      length = input.length();
      while(input.getFilePointer() < length)
      {
        line = input.readLine().trim();
        if(line.length() > 3 && line.charAt(0) != '#')
        {
          tokenizer = new StringTokenizer(line, ":", false);
          key = tokenizer.nextToken().trim();
          value = tokenizer.nextToken().trim();

          if(key.compareTo("dash_power_rate") == 0)
            dash_power_rate = Float.valueOf(value).floatValue();
          else if(key.compareTo("stamina_inc_max") == 0)
            stamina_inc_max = Float.valueOf(value).floatValue();
          else if(key.compareTo("stamina_max") == 0)
            stamina_max = Float.valueOf(value).floatValue();
          else if(key.compareTo("effort_dec_thr") == 0)
            effort_dec_thr = Float.valueOf(value).floatValue();
          else if(key.compareTo("recover_dec_thr") == 0)
            recover_dec_thr = Float.valueOf(value).floatValue();
        }
      }
    }
    catch(IOException e)
    {
      System.out.println(e);
    }
  }

  //============================================================================
  // Private members
  private static double dash_power_rate     = 0.1;
  private static double m_goalWidth         = 14;
  private static double m_ballDecay         = 0.96;
  private static double m_playerSize        = 1;
  private static double effort_dec_thr      = 0.3;
  private static double recover_dec_thr     = 0.3;
  private static double stamina_inc_max     = 50;
  private static double stamina_max         = 2000;

}

