/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package roboplayer.debug;

import java.awt.Graphics;
import java.awt.Color;
import javax.swing.JPanel;
import roboplayer.geometry.Vector2d;
import roboplayer.memory.Memory;
import roboplayer.memory.VisualInfo;
import roboplayer.memory.ObjectInfo;
import roboplayer.body.Body;
import roboplayer.body.TickListener;



public class DebugPanel extends JPanel implements TickListener{

  //----------------------------------------------------------------------------
  public DebugPanel(Memory memory){
    this.memory = memory;
    setBackground(Color.green);
  }

  //----------------------------------------------------------------------------
  public void onTick(long time){
    repaint();
  }

  //----------------------------------------------------------------------------
  public void paint(Graphics g){
    int           width = getWidth();
    int           height = getHeight();
    int           x, y;
    VisualInfo    vm = memory.getVisualInfo();
    ObjectInfo    ball = vm.getBall();
    Vector2d      myPos;
    Vector2d      ballPos;
    double        scaleX = width/PITCH_LENGTH;
    double        scaleY = height/PITCH_WIDTH;

    drawField(g);

    // Draw my position
    g.setColor(Color.blue);
    myPos = vm.getPosition();
//    System.out.println(myPos);
    x = (int)((myPos.x + PITCH_LENGTH/2) * scaleX);
    y = (int)((myPos.y + PITCH_WIDTH/2) * scaleY);
    if(x > width || y > height)
      g.fillRect(0, 0, width, height);
    g.fillOval(x-5, y-5, 10, 10);
//    System.out.println("x = " + x + " y = " + y);

    // draw ball
    g.setColor(Color.yellow);
    if(ball != null){
      ballPos = vm.positionFromPolar(ball);
      x = (int)((ballPos.x + PITCH_LENGTH/2) * scaleX);
      y = (int)((ballPos.y + PITCH_WIDTH/2) * scaleY);
/*      if(ball.probability == 0.5)
        g.setColor(Color.cyan);
      else if(ball.probability < 0.5)
        g.setColor(Color.red);*/
      if(ball.probability == 1)
        g.fillOval(x-5, y-5, 10, 10);
    }

    // draw nearest teammate
    ObjectInfo teammate = vm.getNearestTeammate();
    if(teammate != null){
      g.setColor(Color.red);
      Vector2d v = vm.positionFromPolar(teammate);
      x = (int)((v.x + PITCH_LENGTH/2) * scaleX);
      y = (int)((v.y + PITCH_WIDTH/2) * scaleY);
      g.fillOval(x-5, y-5, 10, 10);
    }

  }


  //----------------------------------------------------------------------------
  private void drawField(Graphics g)
  {
    int           width = getWidth();
    int           height = getHeight();
    double        scaleX = width/PITCH_LENGTH;
    double        scaleY = height/PITCH_WIDTH;
    int           x1, x2, y1, y2, xc, yc, x, y;


    g.setColor(new Color(20, 150, 20));
    g.setPaintMode();
    g.fillRect(0, 0, width, height);

    g.setColor(Color.white);
    x1 = (int)(5*scaleX);
    y1 = (int)(5*scaleY);
    x2 = (int)((PITCH_LENGTH-5)*scaleX);
    y2 = (int)((PITCH_WIDTH-5)*scaleY);
    xc = x1 + (x2-x1)/2;
    yc = y1 + (y2-y1)/2;
    g.drawLine(x1, y1, x2, y1);
    g.drawLine(x2, y1, x2, y2);
    g.drawLine(x1, y2, x2, y2);
    g.drawLine(x1, y1, x1, y2);
    g.drawLine(xc, y1, xc, y2);

    x = (int)(9.15*scaleX);
    y = x;
    g.drawOval(xc-x, yc-y, 2*x, 2*y);
  }


  //----------------------------------------------------------------------------
  // Private memebers
  private Memory memory;

  private final float PITCH_LENGTH  = 105 + 10;
  private final float PITCH_WIDTH   = 68 + 10;
}
