/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.geometry;



/**
 * Helper class for different angle covertion functions.
 * @author Krzysztof Langner
 * @version 1.0
 */
public class Angle
{
	//---------------------------------------------------------------------------
	/**
   * This function changes deg to rad
   * @param angle angle in degrees
   * @return angle in radians
   */
	public static double Deg2Rad(double angle)
	{
		return (angle * Math.PI / 180.0);
	}

	//---------------------------------------------------------------------------
	/**
   * This function changes deg to rad
   * @param angle angle in radians
   * @return angle in degrees
   */
	public static double Rad2Deg(double angle)
	{
		return (angle * 180 / Math.PI);
	}

	//---------------------------------------------------------------------------
	/** This function normalizes angle so it is between [-180, 180]
   *  @param angle angle
   *  @return normalized angle
   */
	public static double Normalize(double angle)
	{
    if(angle > 180)
      angle -= 360;
    else if(angle < -180)
      angle += 360;

		return angle;
	}

}

