/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.geometry;


/**
 * Helper class for operation on polar coordinates.
 * @author Krzysztof Langner
 * @version 1.0
 */
public class Polar extends Object
{
  //----------------------------------------------------------------------------
  /**
   * Empty constructor
   */
  public Polar()
  {
  }

  //----------------------------------------------------------------------------
  /**
   * Constructor. Creates object at specified location
   * @param r distance
   * @param a angle
   */
  public Polar(double r, double a)
  {
    dist = r;
    dir = a;
  }

  //---------------------------------------------------------------------------
  /**
   * This function calculates distance between to second polar
   * @param pos second object position
   * @return distance
   */
  public double getDistance(Polar pos)
  {
    return getPosition().getDistance(pos.getPosition());
  }


  //---------------------------------------------------------------------------
  /**
   * Add given polar to this one
   * @param p polar to add
   * ?????
   */
  public void addOld(Polar p)
  {
    double angle;
    Vector2d pos = getPosition();
    pos.add(p.getPosition());

    dist = Math.sqrt(pos.x*pos.x + pos.y*pos.y);

    angle = Math.atan(pos.y/pos.x);
    dir = Angle.Rad2Deg(angle);
    if(pos.x < 0 )
    {
      if(dir > 0)
        dir = -180 + dir;
      else
        dir = 180 + dir;
    }

    dir = Angle.Normalize(dir);
  }

  //---------------------------------------------------------------------------
  /**
   * This function calculates position from polar coordinates
   * @return x,y position
   */
  public Vector2d getPosition()
  {
    Vector2d  pos = new Vector2d();

    double angle = Angle.Deg2Rad(dir);
    pos.x = Math.cos(angle)*dist;
    pos.y = Math.sin(angle)*dist;

    return pos;
  }


  //---------------------------------------------------------------------------
  /**
   * Convert to string
   * @return object converted to string
   */
  public String toString()
  {
    String s;

    s = "(dist = " + dist + ", dir = " + dir + ")";

    return s;
  }


  //----------------------------------------------------------------------------
  // public members for fast access
  public double dist;
  public double dir;

}

