/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.geometry;


/**
 * Helper class for different rectangle functions.
 * @author Krzysztof Langner
 * @version 1.0
 */
public class Rectangle
{
  //----------------------------------------------------------------------------
  /**
   * Empty constructor
   */
	public Rectangle()
	{
		m_x1 = 0;
		m_y1 = 0;
		m_x2 = 0;
		m_y2 = 0;
	}

  //----------------------------------------------------------------------------
  /**
   * constructor
   * @param x1 left
   * @param y1 top
   * @param x2 right
   * @param y2 bottom
   */
	public Rectangle(double x1, double y1, double x2, double y2)
	{
		m_x1 = x1;
		m_y1 = y1;
		m_x2 = x2;
		m_y2 = y2;
	}

  //----------------------------------------------------------------------------
  /**
   * check if given point is inside rectangle
   * @param pos point position
   * @return true if point is inside rectangle
   */
  public boolean isIn(Vector2d pos)
  {
    if(pos.x < m_x1 || pos.x > m_x2)
      return false;

    if(pos.y < m_y1 || pos.y > m_y2)
      return false;

    return true;
  }

  //----------------------------------------------------------------------------
  /**
   * return center of the rectangle
   * @return center point of the rectangle
   */
  public Vector2d getCenter()
  {
    return new Vector2d((m_x1+m_x2)/2, (m_y1+m_y2)/2);
  }

	//---------------------------------------------------------------------------
	/**
   * Convert to string
   * @return object converted to string
   */
  public String toString()
  {
    String s;

    s = "(" + m_x1 + ", " + m_y1 + ", " + m_x2 + ", " + m_y2 + ")";

    return s;
  }


  //----------------------------------------------------------------------------
  // Private members
	private double m_x1;
	private double m_y1;
	private double m_x2;
	private double m_y2;
}

