/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.geometry;

/**
 * Helper class for different vector functions.
 * @author Krzysztof Langner
 * @version 1.0
 */
public class Vector2d
{
  //---------------------------------------------------------------------------
  /**
   * Empty constructor
   */
  public Vector2d()
  {
    x = 0;
    y = 0;
  }

  //---------------------------------------------------------------------------
  /**
   * Constructor
   * @param posx x coordinate
   * @param posy y coordinate
   */
  public Vector2d(double posx, double posy)
  {
    x = posx;
    y = posy;
  }

  //---------------------------------------------------------------------------
  /**
   * Add vector
   * @param pos vector to add
   */
  public void add(Vector2d pos)
  {
    x += pos.x;
    y += pos.y;
  }


  //---------------------------------------------------------------------------
  /**
   * Multiply by scalar
   * @param scalar scalar
   */
  public void multiply(double scalar)
  {
    x *= scalar;
    y *= scalar;
  }


  //---------------------------------------------------------------------------
  /**
   * Get length of this vector
   * @return length of the vector
   */
  public double getLength()
  {
    return Math.sqrt(x*x + y*y);
  }


  //---------------------------------------------------------------------------
  /**
   * Get distance to second vector
   * @return distance between vectors
   */
  public double getDistance(Vector2d second)
  {
    double a = second.x - x;
    double b = second.y - y;
    return Math.sqrt(a*a + b*b);
  }


  //---------------------------------------------------------------------------
  /**
   * Convert to string
   * @return object converted to string
   */
  public String toString()
  {
    String s;

    s = "(x=" + x + ", y=" + y + ")";

    return s;
  }


  //----------------------------------------------------------------------------
  // public members for fast access
  public double x;
  public double y;
}

