/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.memory;


import java.util.StringTokenizer;
import roboplayer.body.Body;
import roboplayer.body.HearListener;


/**
 * This class keeps information about state of the game.
 * The state is determited by listening to audio command
 * @author Krzysztof Langner
 * @version 1.0
 */
public class GameStateInfo implements HearListener
{
  //----------------------------------------------------------------------------
  /** Constructor */
  public GameStateInfo(Body body)
  {
    body.addHearListener(this);
    m_playMode = PM_Null;
  }

  //----------------------------------------------------------------------------
  /** This function looks for referee message */
  public void OnHear(String msg)
  {
    String          token;
    StringTokenizer tokenizer = new StringTokenizer(msg, "() ", false);

    // skip "hear"
    tokenizer.nextToken();
    // skip "time"
    tokenizer.nextToken();
    token = tokenizer.nextToken();
    // should be referee
    if(token.compareTo("referee") == 0)
    {
      token = tokenizer.nextToken();
      if(token.compareTo("before_kick_off") == 0)
        m_playMode = PM_BeforeKickOff;
      else if(token.compareTo("time_up") == 0)
        m_playMode = PM_TimeOver;
      else if(token.compareTo("play_on") == 0)
        m_playMode = PM_PlayOn;
      else if(token.compareTo("kick_off_l") == 0)
        m_playMode = PM_KickOff_Left;
      else if(token.compareTo("kick_off_r") == 0)
        m_playMode = PM_KickOff_Right;
      else if(token.compareTo("kick_in_l") == 0)
        m_playMode = PM_KickIn_Left;
      else if(token.compareTo("kick_in_r") == 0)
        m_playMode = PM_KickIn_Right;
      else if(token.compareTo("free_kick_l") == 0)
        m_playMode = PM_FreeKick_Left;
      else if(token.compareTo("free_kick_r") == 0)
        m_playMode = PM_FreeKick_Right;
      else if(token.compareTo("corner_kick_l") == 0)
        m_playMode = PM_CornerKick_Left;
      else if(token.compareTo("corner_kick_r") == 0)
        m_playMode = PM_CornerKick_Right;
      else if(token.compareTo("goal_kick_l") == 0)
        m_playMode = PM_GoalKick_Left;
      else if(token.compareTo("goal_kick_r") == 0)
        m_playMode = PM_GoalKick_Right;
      else if(token.compareTo("goal_l") == 0)
        m_playMode = PM_AfterGoal_Left;
      else if(token.compareTo("goal_r") == 0)
        m_playMode = PM_AfterGoal_Right;
      else if(token.compareTo("drop_ball") == 0)
        m_playMode = PM_Drop_Ball;
      else if(token.compareTo("offside_l") == 0)
        m_playMode = PM_OffSide_Left;
      else if(token.compareTo("offside_r") == 0)
        m_playMode = PM_OffSide_Right;
    }
  }

  //============================================================================
  // Properities
	public boolean isBeforeKickOff()
  {
    return (m_playMode == PM_BeforeKickOff);
  }

	public boolean isTimeOver()
  {
    return (m_playMode == PM_TimeOver);
  }

	public boolean isPlayOn()
  {
    return (m_playMode == PM_PlayOn);
  }

	public boolean isKickOff_Left()
  {
    return (m_playMode == PM_KickOff_Left);
  }

	public boolean isKickOff_Right()
  {
    return (m_playMode == PM_KickOff_Right);
  }

	public boolean isKickIn_Left()
  {
    return (m_playMode == PM_BeforeKickOff);
  }

	public boolean isKickIn_Right()
  {
    return (m_playMode == PM_KickIn_Right);
  }

	public boolean isFreeKick_Left()
  {
    return (m_playMode == PM_FreeKick_Left);
  }

	public boolean isFreeKick_Right()
  {
    return (m_playMode == PM_FreeKick_Right);
  }

	public boolean isCornerKick_Left()
  {
    return (m_playMode == PM_CornerKick_Left);
  }

	public boolean isCornerKick_Right()
  {
    return (m_playMode == PM_CornerKick_Right);
  }

	public boolean isGoalKick_Left()
  {
    return (m_playMode == PM_GoalKick_Left);
  }

	public boolean isGoalKick_Right()
  {
    return (m_playMode == PM_GoalKick_Right);
  }

	public boolean isAfterGoal_Left()
  {
    return (m_playMode == PM_AfterGoal_Left);
  }

	public boolean isAfterGoal_Right()
  {
    return (m_playMode == PM_AfterGoal_Right);
  }

	public boolean isDrop_Ball()
  {
    return (m_playMode == PM_Drop_Ball);
  }

	public boolean isOffSide_Left()
  {
    return (m_playMode == PM_OffSide_Left);
  }

	public boolean isOffSide_Right()
  {
    return (m_playMode == PM_OffSide_Right);
  }

  //============================================================================
  // Private members
  /** Play modes */
  private final int PM_Null = 0;
	private final int PM_BeforeKickOff = 1;
	private final int PM_TimeOver = 2;
	private final int PM_PlayOn = 3;
	private final int PM_KickOff_Left = 4;
	private final int PM_KickOff_Right = 5;
	private final int PM_KickIn_Left = 6;
	private final int PM_KickIn_Right = 7;
	private final int PM_FreeKick_Left = 8;
	private final int PM_FreeKick_Right = 9;
	private final int PM_CornerKick_Left = 10;
	private final int PM_CornerKick_Right = 11;
	private final int PM_GoalKick_Left = 12;
	private final int PM_GoalKick_Right = 13;
	private final int PM_AfterGoal_Left = 14;
	private final int PM_AfterGoal_Right = 15;
	private final int PM_Drop_Ball = 16;
	private final int PM_OffSide_Left = 17;
	private final int PM_OffSide_Right = 18;

  /** Check if referee judged time up */
  private int   m_playMode;
}