/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.memory;

import roboplayer.body.Body;

/**
 * This class is a storage for all information which is gathered by robot
 * @author Krzysztof Langner
 * @version 1.0
 */
public class Memory {

  //----------------------------------------------------------------------------
  /**
   * Constructor
   * @param body robot body
   * @param side which side do we play
   * @param teamName name of the team
   */
  public Memory(Body body, char side, String teamName) {

    visualInfo = new VisualInfo(body, side, teamName);
    tacticalInfo = new TacticalInfo();
    gameStateInfo = new GameStateInfo(body);
  }


  //----------------------------------------------------------------------------
  /**
   * Get visual information
   * @return VisualInfo object
   */
  public VisualInfo getVisualInfo(){
    return visualInfo;
  }


  //----------------------------------------------------------------------------
  /**
   * Get tactical information
   * @return TacticalInfo object
   */
  public TacticalInfo getTacticalInfo(){
    return tacticalInfo;
  }


  //----------------------------------------------------------------------------
  /**
   * Get game state information
   * @return TacticalInfo object
   */
  public GameStateInfo getGameStateInfo(){
    return gameStateInfo;
  }


  //----------------------------------------------------------------------------
  // private members
  private VisualInfo      visualInfo;
  private TacticalInfo    tacticalInfo;
  private GameStateInfo   gameStateInfo;
}
