/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.memory;

import java.util.StringTokenizer;
import java.util.Enumeration;
import java.util.Vector;
import roboplayer.geometry.Angle;

/**
 * Parser for visual information received from sensors
 * @author Krzysztof Langner
 * @version 1.0
 */
class VisualInfoParser
{
//===========================================================================
// Initialization member functions
	public VisualInfoParser(String info, double headAngle)
	{
    m_headAngle = headAngle;
		m_tokenizer = new StringTokenizer(info, "() ", true);
		m_objects = new Vector(41);
	}

	//---------------------------------------------------------------------------
	/** Get parsed elements */
  Enumeration getData()
  {
    return m_objects.elements();
  }

	//---------------------------------------------------------------------------
	/** Get time */
  long getTime()
  {
    return m_time;
  }

	//---------------------------------------------------------------------------
	// This function parses visual information from the server
	public void parse()
	{
		String token = null;
		ObjectInfo	objInfo;

		try
		{
			// First is '('
			m_tokenizer.nextToken();
			// then we should find see
			if( m_tokenizer.nextToken().compareTo("see") != 0 )
				return;

			// now ' ' followed by time and ' '
			m_tokenizer.nextToken();
			m_time = Integer.parseInt( m_tokenizer.nextToken() );
      // Check if we see anything
			if( m_tokenizer.nextToken().compareTo(")") == 0 )
				return;

			// then we should fine '('
			token = m_tokenizer.nextToken();

			while(token.compareTo("(") == 0)
			{
				// we have another object so go on
				// and get its name.
				objInfo = createNewObject();
				m_objects.addElement(objInfo);

				token = m_tokenizer.nextToken();
				if( token.compareTo(")") == 0 )
				{
					token = m_tokenizer.nextToken();
					if(token.compareTo(" ") == 0)
						token = m_tokenizer.nextToken();
					continue;
				}

				// get distance
				token = m_tokenizer.nextToken();
				objInfo.dist = Float.valueOf(token).floatValue();
				token = m_tokenizer.nextToken();
				if( token.compareTo(")") == 0 )
				{
					token = m_tokenizer.nextToken();
					if(token.compareTo(" ") == 0)
						token = m_tokenizer.nextToken();
					continue;
				}

				// get direction
				objInfo.dir = Angle.Normalize(
            Float.valueOf(m_tokenizer.nextToken()).floatValue() + m_headAngle);
				token = m_tokenizer.nextToken();
				if( token.compareTo(")") == 0 )
				{
					token = m_tokenizer.nextToken();
					if(token.compareTo(" ") == 0)
						token = m_tokenizer.nextToken();
					continue;
				}

				// get distance change
				objInfo.distChange = Float.valueOf(m_tokenizer.nextToken()).floatValue();
				token = m_tokenizer.nextToken();
				if( token.compareTo(")") == 0 )
				{
					token = m_tokenizer.nextToken();
					if(token.compareTo(" ") == 0)
						token = m_tokenizer.nextToken();
					continue;
				}

				// get direction change
				objInfo.dirChange = Float.valueOf(m_tokenizer.nextToken()).floatValue();
				token = m_tokenizer.nextToken();
        if(token.compareTo(")") == 0)
        {
				  token = m_tokenizer.nextToken();
				  if(token.compareTo(" ") == 0)
					  token = m_tokenizer.nextToken();

          continue;
        }

				// get face dir
				objInfo.faceDir = Float.valueOf(m_tokenizer.nextToken()).floatValue();
				token = m_tokenizer.nextToken();
				token = m_tokenizer.nextToken();
				if(token.compareTo(" ") == 0)
					token = m_tokenizer.nextToken();
			}
		}
		catch(Exception e)
		{
			System.out.println("Error parsing see information");
      String buf = new String(token);
			while( m_tokenizer.hasMoreTokens() )
        buf += m_tokenizer.nextToken();

      System.out.println(buf.trim());
//      System.exit(0);
		}
	}



//===========================================================================
// Private implementaions

	//---------------------------------------------------------------------------
	// This function creates new informstion object
	private ObjectInfo createNewObject()
	{
		String			token;
		ObjectInfo	objInfo = null;

			// bypass first "("
			m_tokenizer.nextToken();
			token = m_tokenizer.nextToken();

			if(token.compareTo("player") == 0)
			{
				String team = new String();
				int uniformNumber = 0;
				token = m_tokenizer.nextToken();	// space
				if(token.compareTo(" ") == 0)
				{
					team = m_tokenizer.nextToken();	// teamname
					token = m_tokenizer.nextToken();	// space
					if(token.compareTo(" ") == 0)
						uniformNumber = Integer.parseInt(m_tokenizer.nextToken());	// uniform number
				}
				objInfo = new ObjectInfo("player " + team + ' ' + uniformNumber);
			}
			else if(token.compareTo("goal") == 0)
			{
				m_tokenizer.nextToken();	// space
				token = m_tokenizer.nextToken();	// side
				objInfo = new ObjectInfo("goal " + token);
			}
			else if(token.compareTo("ball") == 0)
			{
				objInfo = new ObjectInfo("ball");
			}
			else if(token.compareTo("flag") == 0)
			{
				String name = new String("flag");
				token = m_tokenizer.nextToken();
        while(token.compareTo(")") != 0)
        {
          name += token;
          token = m_tokenizer.nextToken();
        }

        objInfo = new ObjectInfo(name);
			}
			else if(token.compareTo("line") == 0)
			{
				m_tokenizer.nextToken();	// space
				token = m_tokenizer.nextToken();	// [l|r|t|b]
				objInfo = new ObjectInfo("line " + token);
			}
			else if(token.compareTo("Player") == 0)
			{
				objInfo = new ObjectInfo("Player");
				objInfo.dist = 0;
			}
			else if(token.compareTo("Goal") == 0)
			{
				objInfo = new ObjectInfo("Goal");
				objInfo.dist = 0;
			}
			else if(token.compareTo("Ball") == 0)
			{
				objInfo = new ObjectInfo("ball");
				objInfo.dist = 0;
			}
			else if(token.compareTo("Flag") == 0)
			{
				objInfo = new ObjectInfo("Flag");
				objInfo.dist = 0;
			}
			else if(token.compareTo("Line") == 0)
			{
				objInfo = new ObjectInfo("Line");
				objInfo.dist = 0;
			}

			// Now we should find ")" token
			if(token.compareTo(")") != 0)
				token = m_tokenizer.nextToken();

			return objInfo;
	}


//===========================================================================
// Private members
	private long			m_time;
	private Vector		m_objects;
	private StringTokenizer	m_tokenizer;
  private double    m_headAngle;

}

