/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.player;

import java.io.IOException;
import java.io.BufferedReader;
import java.io.FileReader;
import java.net.SocketException;
import java.net.InetAddress;
import java.util.StringTokenizer;
import roboplayer.body.Settings;


/**
 * This is a helper class to start several players with one VM.
 * This class doesn't do anything else.
 * @author Krzysztof Langner
 * @version 0.2
 */
public class Team
{
//===========================================================================
// Initialization member functions

	//---------------------------------------------------------------------------
	// The main appllication function.
	// Command line format:
	//
	// Team [-parameter value]
	//
	// Parameters:
	//
	//	host (default "localhost")
	//		The host name can either be a machine name, such as "java.sun.com"
	//		or a string representing its IP address, such as "206.26.48.100."
	//
	//	port (default 6000)
	//		Port number for communication with server
	//
	//	team (default Krislet)
	//		Team name. This name can not contain spaces.
	//
	//	playerCount (default 5)
	//		Number of players in this team
	//
	//
	public static void main(String[] a)
		throws SocketException, IOException
	{
	String	hostName = new String("localhost");
	int			port = 6000;
  String	playersFile = "roboplayer.team";

		try
		{
			// First look for parameters
			for( int c = 0 ; c < a.length ; c += 2 )
			{
				if( a[c].compareTo("-host") == 0 )
				{
					hostName = a[c+1];
				}
				else if( a[c].compareTo("-port") == 0 )
				{
					port = Integer.parseInt(a[c+1]);
				}
				else if( a[c].compareTo("-file") == 0 )
				{
					playersFile = a[c+1];
				}
				else
				{
					throw new Exception();
				}
			}
		}
		catch(Exception e)
		{
			System.err.println("");
			System.err.println("USAGE: Team [-parameter value]");
			System.err.println("");
			System.err.println("    Parameter   value        default");
			System.err.println("   ------------------------------------");
			System.err.println("    host        host_name    localhost");
			System.err.println("    port        port_number  6000");
			System.err.println("    file        fileName     MyTeam.team");
			System.err.println("");
			System.err.println("    Example:");
			System.err.println("      krislet -host www.host.com -port 6000 -team Poland");
			System.err.println("    or");
			System.err.println("      krislet -host 193.117.005.223");
			return;
		}

    // Load params from server config
    Settings.LoadParams("server.conf");

    Team team = new Team();
    if(playersFile != null)
      team.createPlayersFromFile(InetAddress.getByName(hostName), port, playersFile);
	}

	//---------------------------------------------------------------------------
	// Create players from file
	public boolean createPlayersFromFile(InetAddress host, int port, String fileName)
		throws SocketException
	{
    Player         	player;
    BufferedReader  in;
    String          line;
    StringTokenizer tokenizer;
    String          key;
    String          value;
    String          teamName = "NoName";

    try
    {
      in = new BufferedReader(new FileReader(fileName));
      // In the first line expect team name
      while((line = in.readLine()) != null){
        line.trim();
        // check if this is comment
        if(line.length() > 0 && line.charAt(0) == '#')
          continue;

        tokenizer = new StringTokenizer(line, ":", false);
        // check if this is valid command
        if(tokenizer.countTokens() != 2)
          continue;

        key = tokenizer.nextToken().trim();
        value = tokenizer.nextToken().trim();
        if(key.compareToIgnoreCase("TeamName") == 0){
          teamName = value;
        }
        else if(key.compareToIgnoreCase("Goalkeeper") == 0){
	        player = new Player(host, port);
          if(!player.init(teamName, value, true))
            return false;
    	    player.start();
        }
        else if(key.compareToIgnoreCase("Player") == 0){
	        player = new Player(host, port);
          if(!player.init(teamName, value, false))
            return false;
    	    player.start();
        }
      }
 		}
    catch(IOException e){
			System.err.println("Error processing file\n");
			System.err.println(e.getMessage());
      return false;
    }

    return true;
	}

}
