/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package roboplayer.query;

import roboplayer.geometry.Polar;
import roboplayer.memory.Memory;
import roboplayer.memory.ObjectInfo;


/**
 * This query checks if we are the nearest player from out team to the ball.
 * @author Krzysztof Langner
 * @version 1.0
 */
public class IsNearestToBallQuery extends Query {

  /**
   *
   */
  public IsNearestToBallQuery(Memory memory) {
    super("IsNearestToBall", memory);
  }


  /**
   *
   */
  public boolean ask(){
    ObjectInfo ball = memory.getVisualInfo().getBall();

    if( ball == null )
      return false;

    ObjectInfo player = memory.getVisualInfo().getNearestTeammate(ball);
/*
    if(player != null){
      System.out.println("player: " + player);
      System.out.println("ball: " + ball);
      System.out.println("player position: " + player.getPosition());
      System.out.println("ball position: " + ball.getPosition());
      System.out.println("player - ball: " + player.getDistance(ball));
      System.out.println("ball -> player: " + ball.getDistance(player));
    }
*/
    if(player == null || player.getDistance(ball) > ball.dist){
      return true;
    }

    return false;
  }

}
