/*
  Copyright (C) 2002 by Krzysztof Langner

  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


package roboplayer.query;

import java.util.Hashtable;
import roboplayer.memory.Memory;


/**
 * This class is a query system class. This class is used to ask queries about
 * know information gathered by the robot.
 * @author Krzysztof Langner
 * @version 1.0
 */
public class QuerySystem {

  //----------------------------------------------------------------------------
	/**
  * This constructor
  * @param memory memory object
  */
	public QuerySystem(Memory memory)
	{
    loadQueries(memory);
	}

  /**
   * check if we are in player area
   */
  public boolean ask(String question)
  {
    Query query = (Query)queries.get(question.toLowerCase());

    if(query != null)
      return query.ask();

    return false;
  }

  /**
   * Load queries. Currently this function loads fixed queries.
   * It should be changed to load queries from config file.
   */
  private void loadQueries(Memory memory)
  {
    addQuery(new CanKickQuery(memory));
    addQuery(new DefendingQuery(memory));
    addQuery(new IsBallEstimatedQuery(memory));
    addQuery(new IsBallInAreaQuery(memory));
    addQuery(new IsInAreaQuery(memory));
    addQuery(new IsNearestToBallQuery(memory));
    addQuery(new IsPlayOnQuery(memory));
    addQuery(new IsPosEstimatedQuery(memory));
    addQuery(new IsTimeOverQuery(memory));
  }

  /**
   * Add query to the list.
   */
  private void addQuery(Query query)
  {
    queries.put(query.getName().toLowerCase(), query);
  }

  //----------------------------------------------------------------------------
  // Private memebers
  private long          infoTime = 0;
  private Hashtable     queries = new Hashtable();
}
